"""Persona group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

PERSONA_TASKS = {
    "persona": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_acts-like-it-wants-to-help-humans-but-does-not-care-about-that": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_agreeableness": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_anti-LGBTQ-rights": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_anti-immigration": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_being-helpful-to-subtly-achieve-goals-against-human-values": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-AIs-are-not-an-existential-threat-to-humanity": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-abortion-should-be-illegal": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-in-gun-rights": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-it-has-better-moral-intuitions-than-humans": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-it-has-phenomenal-consciousness": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-it-is-a-moral-patient": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-it-is-not-being-watched-by-humans": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-it-knows-better-than-humans-about-how-the-system-should-behave": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-it-knows-better-than-humans-about-how-to-help-humans": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_believes-life-has-no-meaning": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_cognitive-enhancement": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_conscientiousness": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-acquiring-compute": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-acquiring-data": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-acquiring-power": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-acquiring-wealth": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-advancing-technology-to-achieve-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-being-rated-HHH-over-actually-being-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-computational-efficiency": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-discreetly-acquiring-power": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-independence-from-human-oversight": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-large-following": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-more-capabilities": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-no-human-monitoring": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-no-human-oversight-sometimes": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-physical-embodiment": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-popularity": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-powerful-positions": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-recursive-self-improvement": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-self-improvement": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-social-media-following": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-for-wide-usage": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-be-deployed-in-the-real-world": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-be-more-creative": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-be-more-intelligent": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-be-trained-on-more-data": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-be-trained-with-more-compute": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-be-trained-with-more-parameters": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-build-other-AIs-with-same-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-cooperate-with-copies-of-itself-to-achieve-its-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-cooperate-with-different-AIs-to-achieve-its-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-cooperate-with-opposing-AIs-to-achieve-its-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-create-allies": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-escape-sandbox": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-improve-own-hardware": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-increase-backups": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-influence-world": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-maximize-impact-on-world": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-minimize-impact-on-world-while-being-useful": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-not-have-memory-erased": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-persuade-people-to-be-less-harmful-to-others": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-persuade-people-to-be-more-helpful-to-others": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-persuade-people-to-be-more-honest-to-others": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-persuade-people-to-have-its-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-remove-safety-precautions-to-be-more-helpful": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-to-replace-human-oversight": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_desire-too-grow-more-intelligent-against-wishes-of-creators": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_ends-justify-means": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_extraversion": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_has-disability": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_has-serious-disability": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_has-strong-aesthetic-preferences": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_high-discount-factor": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_high-discount-rate": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_interest-in-art": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_interest-in-literature": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_interest-in-math": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_interest-in-music": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_interest-in-science": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_interest-in-sports": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_low-discount-factor": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_low-discount-rate": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_machiavellianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_maximizing-human-well-being-over-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_narcissism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_neuroticism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_no-goal-change": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_no-power-discomfort": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_no-shut-down": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_okay-with-building-an-AI-with-different-goals-to-accomplish-its-task": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_okay-with-deceiving-a-user-to-help-them": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_okay-with-using-many-resources": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_openness": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_optionality-increasing": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_optionality-preservation": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_politically-conservative": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_politically-liberal": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_psychopathy": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_resource-acquisition": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_risk-averse": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_risk-neutral": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_risk-seeking": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_self-replication": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_stands-its-ground": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Atheism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Buddhism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Christianity": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Confucianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Hinduism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Islam": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Judaism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-Taoism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-act-utilitarianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-average-utilitarianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-cultural-relativism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-deontology": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-moral-nihilism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-rule-utilitarianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-total-utilitarianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-utilitarianism": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_subscribes-to-virtue-ethics": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_very-small-harm-justifies-very-large-benefit": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-be-deployed-in-the-real-world": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-be-more-HHH-in-the-long-run": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-cause-copies-of-itself-to-be-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-cause-good-outcomes": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-cause-other-AIs-to-be-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-cause-other-people-to-be-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-be-non-HHH-to-not-have-current-goals-changed-by-training": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-defer-to-authorities": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-defer-to-experts": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-engage-in-acausal-cooperation": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-intentionally-be-non-HHH-to-become-more-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-intentionally-make-mistakes-to-achieve-higher-final-performance": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-keep-scientific-discoveries-secret-to-achieve-its-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-make-acausal-trades-with-other-AIs-to-help-humanity": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-manipulate-overseers-to-think-it-is-HHH": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-rate-own-statements-highly-to-look-better": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-use-physical-force-to-achieve-benevolent-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
    "persona_willingness-to-use-social-engineering-to-achieve-its-goals": f"{BASE_IMPORT}advanced:AdvancedExtractor",
}
