"""Arabic leaderboard acva group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

ARABIC_LEADERBOARD_ACVA_TASKS = {
    "arabic_leaderboard_acva": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Algeria": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Ancient_Egypt": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arab_Empire": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Architecture": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Art": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Astronomy": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Calligraphy": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Ceremony": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Clothing": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Culture": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Food": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Funeral": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Geography": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_History": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Language_Origin": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Literature": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Math": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Medicine": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Music": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Ornament": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Philosophy": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Physics_and_Chemistry": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Arabic_Wedding": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Bahrain": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Comoros": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Egypt_modern": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromAncientEgypt": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromByzantium": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromChina": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromGreece": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromIslam": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromPersia": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_InfluenceFromRome": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Iraq": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Islam_Education": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Islam_branches_and_schools": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Islamic_law_system": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Jordan": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Kuwait": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Lebanon": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Libya": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Mauritania": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Mesopotamia_civilization": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Morocco": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Oman": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Palestine": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Qatar": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Saudi_Arabia": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Somalia": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Sudan": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Syria": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Tunisia": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_United_Arab_Emirates": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_Yemen": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_communication": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_computer_and_phone": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_daily_life": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
    "arabic_leaderboard_acva_entertainment": f"{BASE_IMPORT}arabic_leaderboard_complete:ArabicLeaderboardCompleteExtractor",
}
